Ebooklib-re
==============

Fork of Ebooklib which exists solely to sync upstream updates missing from the PyPi release, while the author doesn't update the original.

License
=======

EbookLib is licensed under the AGPL license.


Authors
=======

Full list of authors is in AUTHORS.txt file.
